#include "string.h"
#include "stdlib.h"

#include "SDL.h"
#include "SDL_ttf.h"

#include "BList.h"
#include "auxiliar.h"
#include "MOG2_auxiliar.h"

#include "variables.h"
#include "mog2.h"

#include "BWindow.h"
#include "BActiveWindow.h"
#include "BStringEdDlg.h"
#include "BIntegerEdDlg.h"
#include "BFileListWnd.h"
#include "BChoiceDlg.h"

#include "MTopWnd.h"

#include "GrabTopWnd.h"

#include "BFileDlg.h"
#include "interfaces.h"

#include "editor.h"

#ifdef KITSCHY_DEBUG_MEMORY 
#include "debug_memorymanager.h"
#endif

const int mini_map_size=128;

GrabTopWnd::GrabTopWnd(int x,int y,int dx,int dy,EDITOR *e,TTF_Font *font) : BWindow(x,y,dx,dy,font) 
{
	BButton *b;

	editor=e;

	b=new BButton(0,0,64,16,"BACK",1);
	buttons.Add(b);
	b=new BButton(64,0,64,16,"LOAD",2);
	buttons.Add(b);
	b=new BButton(128,0,64,16,"SAVE",3);
	buttons.Add(b);
} /* GrabTopWnd::GrabTopWnd */ 


GrabTopWnd::~GrabTopWnd()
{
} /* GrabTopWnd::~GrabTopWnd */ 



void GrabTopWnd::contens_size(int *dx,int *dy)
{
	*dx=old_dx;
	*dy=old_dy;
} /* GrabTopWnd::contens_size */ 


void GrabTopWnd::draw_contens(SDL_Surface *sfc,int stx,int sty,int dx,int dy)
{
	SDL_FillRect(sfc,0,0);

	BWindow::draw_contens(sfc,stx,sty,dx,dy);

	draw_button(sfc,192-stx,0-sty,sfc->w-192,16,"Maze of Galious 2 - EDITOR / GRABBER VIEW",font,false);
} /* GrabTopWnd::draw_contens */ 


bool GrabTopWnd::button_pressed(int ID)
{
	switch(ID) {
	case 1:
		/* BACK */ 
		editor->view=OBJECT_VIEW;
		editor->ov_selected=0;
		editor->ov_selected_ob=-1;
		if (editor->grabv_bitmap!=0) {
			SDL_FreeSurface(editor->grabv_bitmap);
			editor->grabv_bitmap=0;
		} /* if */ 
		break;
	case 2:
		/* LOAD: */ 
		{
			char tmp[256]="*.mg2";
			BFileDlg *dlg=new BFileDlg(30,30,200,200,"Choose a game to load","Load",tmp,editor->font);

			dlg->Execute();
			delete dlg;

			if (tmp[0]!=0) {
				FILE *fp;
				fp=fopen(tmp,"r");

				if (fp!=0) {
					MOG2 *newgame;
					newgame=new MOG2();
					if (newgame->load(fp)) {
						delete editor->game;
						editor->game=newgame;
						editor->map=0;
						editor->room=0;
						editor->view=GAME_VIEW;

						if (editor->grabv_bitmap!=0) {
							SDL_FreeSurface(editor->grabv_bitmap);
							editor->grabv_bitmap=0;
						} /* if */ 
					} else {
						int res;
						BChoiceDlg *dlg2=new BChoiceDlg(40,40,200,50,"Error loading file","Accept",&res,editor->font);
						dlg2->Execute();
						delete dlg2;
						delete newgame;
					} /* if */ 
					fclose(fp);
				} else {
					int res;
					BChoiceDlg *dlg2=new BChoiceDlg(40,40,200,50,"Cannot open file for loading","Accept",&res,editor->font);
					dlg2->Execute();
					delete dlg2;
				} /* if */ 
			} /* if */ 
		}
		break;
	case 3:
		/* SAVE: */ 
		{
			char tmp[256]="*.mg2";
			BFileDlg *dlg=new BFileDlg(30,30,200,200,"Save your game","Save",tmp,editor->font);

			dlg->Execute();
			delete dlg;

			if (tmp[0]!=0) {
				FILE *fp;
				int res=0;

				fp=fopen(tmp,"r");
				if (fp!=0) {
					BChoiceDlg *dlg2=new BChoiceDlg(40,40,200,50,"File already exist!","Overwrite",&res,editor->font);
					dlg2->Execute();
					delete dlg2;

					fclose(fp);
					if (res==1) {
						fp=fopen(tmp,"w");

						if (fp!=0) {
							editor->game->save(fp);
							fclose(fp);
						} else {
							BChoiceDlg *dlg2=new BChoiceDlg(40,40,200,50,"Cannot open file for saving","Accept",&res,editor->font);
							dlg2->Execute();
							delete dlg2;
						} /* if */ 
					} /* if */ 
				} else {
					fp=fopen(tmp,"w");

					if (fp!=0) {
						editor->game->save(fp);
						fclose(fp);
					} else {
						BChoiceDlg *dlg2=new BChoiceDlg(40,40,200,50,"Cannot open file for saving","Accept",&res,editor->font);
						dlg2->Execute();
						delete dlg2;
					} /* if */ 
				} /* if */ 
				
			} /* if */ 
		}
		break;

	case 4:
		/* Enter the Object Editor: */ 
		editor->ov_last_view=editor->view;
		editor->view=OBJECT_VIEW;
		break;

	default:
		break;
	} /* switch */ 

	return true;
} /* GrabTopWnd::button_pressed */ 
